from sklearn.cluster import KMeans
import numpy as np

def perform_kmeans_clustering(data, n_clusters):
    """
    Perform k-means clustering on 1D data.
    
    Args:
        data: A 1D numpy array or list of numbers to cluster
        n_clusters: The number of clusters to create
        
    Returns:
        A list of lists, where each inner list contains the data points for one cluster
    """
    # Convert to numpy array if not already
    data = np.array(data)
    
    # Reshape data for KMeans (needs a 2D array)
    X = data.reshape(-1, 1)
    
    # Create a KMeans model
    kmeans = KMeans(n_clusters=n_clusters, random_state=0, n_init=10)
    
    # Fit the model to the data
    kmeans.fit(X)
    
    # Get cluster assignments for each data point
    labels = kmeans.labels_
    
    # Get the cluster centers
    centroids = kmeans.cluster_centers_
    
    # Calculate how well the model fits the data (sum of squared distances)
    inertia = kmeans.inertia_
    
    # Organize data points by cluster
    cluster_points = []
    for i in range(n_clusters):
        points_in_cluster = data[labels == i]
        cluster_points.append(points_in_cluster)
        #print(f"Cluster {i} (Centroid: {centroids[i][0]:.2f}): {points_in_cluster}")
    
    return cluster_points

# Example usage
if __name__ == "__main__":
    # Sample 1D data: ratings from users
    sample_data = np.array([2, 3, 3, 6, 6, 7, 8, 9, 9, 10])
    k = 7  # Number of clusters
    print("Sample data:", sample_data)
    print("Clustering with k=",k)
    clusters = perform_kmeans_clustering(sample_data, k)
    print("Clusters:", clusters)
    
#    print("\nTrying different numbers of clusters:")
#    for k in range(1, 6):
#        print(f"\nk={k}:")
#        perform_kmeans_clustering(sample_data, k)

